DefaultClassifier

Struct DefaultClassifier 

pub struct DefaultClassifier;
Default failure classifier that treats all errors as failures.

This classifier implements FailureClassifier<Res, Err> for all Res and Err types, meaning it can be used without specifying concrete response/error types at configuration time.

Behavior

  • Ok(_) => not a failure
  • Err(_) => failure

Example

use tower_resilience_core::classifier::{FailureClassifier, DefaultClassifier};

let classifier = DefaultClassifier;

// Works with any Result type - type inference from the result argument
assert!(!FailureClassifier::<String, std::io::Error>::classify(&classifier, &Ok("success".to_string())));
assert!(FailureClassifier::<String, std::io::Error>::classify(&classifier, &Err(std::io::Error::other("fail"))));